@@ -120,8 +120,7 @@ samples.fitted <- array(NA, c(n.keep, N.all))
     
     
 #### Metropolis quantities
-accept.all <- rep(0,4)
-accept <- accept.all
+accept <- rep(0,4)
 proposal.sd.phi <- 0.1
 proposal.sd.rho <- 0.02
 Sigma.post.df <- prior.Sigma.df + K  
@@ -323,15 +322,13 @@ data.precision <- t(X.standardised) %*% X.standardised
         ########################################
         ## Self tune the acceptance probabilties
         ########################################
-        k <- j/100
-        if(ceiling(k)==floor(k))
+        if(ceiling(j/100)==floor(j/100) & j < burnin)
         {
         proposal.sd.phi <- common.accceptrates1(accept[1:2], proposal.sd.phi, 40, 50)
             if(!fix.rho)
             {
                 proposal.sd.rho <- common.accceptrates2(accept[3:4], proposal.sd.rho, 40, 50, 0.5)
             }
-            accept.all <- accept.all + accept
             accept <- c(0,0,0,0)
          }else
         {}
@@ -361,10 +358,10 @@ data.precision <- t(X.standardised) %*% X.standardised
 #### Summarise and save the results 
 ###################################
 #### Compute the acceptance rates
-accept.phi <- 100 * accept.all[1] / accept.all[2]
+accept.phi <- 100 * accept[1] / accept[2]
     if(!fix.rho)
     {
-    accept.rho <- 100 * accept.all[3] / accept.all[4]
+    accept.rho <- 100 * accept[3] / accept[4]
     }else
     {
     accept.rho <- NA    
