@@ -100,8 +100,7 @@ samples.fitted <- array(NA, c(n.keep, K))
     
 
 #### Metropolis quantities
-accept.all <- rep(0,6)
-accept <- accept.all
+accept <- rep(0,6)
 proposal.sd.beta <- 0.01
 proposal.sd.phi <- 0.1
 proposal.sd.rho <- 0.02
@@ -283,8 +282,7 @@ n.islands <- max(W.islands$nc)
     ########################################
     ## Self tune the acceptance probabilties
     ########################################
-    k <- j/100
-        if(ceiling(k)==floor(k))
+        if(ceiling(j/100)==floor(j/100) & j < burnin)
         {
         #### Update the proposal sds
             if(p>2)
@@ -296,7 +294,6 @@ n.islands <- max(W.islands$nc)
             }
         proposal.sd.phi <- common.accceptrates1(accept[3:4], proposal.sd.phi, 40, 50)
             if(!fix.rho) proposal.sd.rho <- common.accceptrates2(accept[5:6], proposal.sd.rho, 40, 50, 0.5)
-        accept.all <- accept.all + accept
         accept <- c(0,0,0,0,0,0)
         }else
         {   
@@ -328,11 +325,11 @@ n.islands <- max(W.islands$nc)
 #### Summarise and save the results 
 ###################################
 #### Compute the acceptance rates
-accept.beta <- 100 * accept.all[1] / accept.all[2]
-accept.phi <- 100 * accept.all[3] / accept.all[4]
+accept.beta <- 100 * accept[1] / accept[2]
+accept.phi <- 100 * accept[3] / accept[4]
     if(!fix.rho)
     {
-    accept.rho <- 100 * accept.all[5] / accept.all[6]
+    accept.rho <- 100 * accept[5] / accept[6]
     }else
     {
     accept.rho <- NA    
